@@ -1,34 +1,28 @@
 #   - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 #
 #   file: lib/Dist/Zilla/Plugin/Manifest/Read.pm
-
-#pod =encoding UTF-8
-#pod
-#pod =head1 COPYRIGHT AND LICENSE
-#pod
-#pod Copyright © 2015 Van de Bugger
-#pod
-#pod This file is part of perl-Dist-Zilla-Plugin-Manifest-Read.
-#pod
-#pod perl-Dist-Zilla-Plugin-Manifest-Read is free software: you can redistribute it and/or modify it
-#pod under the terms of the GNU General Public License as published by the Free Software Foundation,
-#pod either version 3 of the License, or (at your option) any later version.
-#pod
-#pod perl-Dist-Zilla-Plugin-Manifest-Read is distributed in the hope that it will be useful, but
-#pod WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
-#pod PARTICULAR PURPOSE. See the GNU General Public License for more details.
-#pod
-#pod You should have received a copy of the GNU General Public License along with
-#pod perl-Dist-Zilla-Plugin-Manifest-Read. If not, see <http://www.gnu.org/licenses/>.
-#pod
-#pod =cut
-
-# --------------------------------------------------------------------------------------------------
+#
+#   Copyright © 2015 Van de Bugger
+#
+#   This file is part of perl-Dist-Zilla-Plugin-Manifest-Read.
+#
+#   perl-Dist-Zilla-Plugin-Manifest-Read is free software: you can redistribute it and/or modify it
+#   under the terms of the GNU General Public License as published by the Free Software Foundation,
+#   either version 3 of the License, or (at your option) any later version.
+#
+#   perl-Dist-Zilla-Plugin-Manifest-Read is distributed in the hope that it will be useful, but
+#   WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
+#   PARTICULAR PURPOSE. See the GNU General Public License for more details.
+#
+#   You should have received a copy of the GNU General Public License along with
+#   perl-Dist-Zilla-Plugin-Manifest-Read. If not, see <http://www.gnu.org/licenses/>.
+#
+#   - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 
 #pod =for :this This is C<Dist::Zilla::Plugin::Manifest::Read> module documentation. Read this if you are going to hack or
-#pod extend C<Dist-Zilla-Plugin-Manifest-Read>, or use it programmatically.
+#pod extend C<Manifest::Read>, or use it programmatically.
 #pod
-#pod =for :those If you want to have annotated manifest in your source, read the L<user manual|Dist::Zilla::Plugin::Manifest::Read::Manual>.
+#pod =for :those If you want to have annotated source manifest, read the L<user manual|Dist::Zilla::Plugin::Manifest::Read::Manual>.
 #pod General topics like getting source, building, installing, bug reporting and some others are covered
 #pod in the F<README>.
 #pod
@@ -44,7 +38,7 @@
 #pod     # (files not included into distrubution are not iterated):
 #pod     my $files = $self->zilla->plugin_named( 'Manifest::Read' )->find_files();
 #pod     for my $file ( @$files ) {
-#pod         …
+#pod         ...
 #pod     };
 #pod
 #pod =head1 DESCRIPTION
@@ -65,8 +59,8 @@ package Dist::Zilla::Plugin::Manifest::Read;
 use Moose;
 use namespace::autoclean;
 
-# ABSTRACT: Read extended MANIFEST file
-our $VERSION = 'v0.3.2'; # VERSION
+# ABSTRACT: Read annotated source manifest
+our $VERSION = 'v0.3.3'; # VERSION
 
 with 'Dist::Zilla::Role::FileGatherer';
 with 'Dist::Zilla::Role::FileFinder';
@@ -133,8 +127,8 @@ sub _build_manifest_file {
 #pod =method gather_files
 #pod
 #pod This method fulfills L<Dist::Zilla::Role::FileGatherer> role requirement. It adds files listed in
-#pod manifest to distribution. Files marked to exclude from distribution and directories are not added,
-#pod though.
+#pod manifest to distribution (and to C<_files>). Files marked to exclude from distribution and
+#pod directories are not added.
 #pod
 #pod =cut
 
@@ -150,15 +144,15 @@ sub gather_files {
 
 #pod =method find_files
 #pod
-#pod This method fulfills L<Dist::Zilla::Role::FileFinder> role requirement. It returns C<ArrayRef> of
-#pod files (objects of C<Dist::Zilla::File::OnDisk> class), listed in manifest and marked for inclusion
-#pod to the distribution.
+#pod This method fulfills L<Dist::Zilla::Role::FileFinder> role requirement. It simply returns a copy of
+#pod C<_files> attribute.
 #pod
 #pod This method can be called by other plugins to iterate through files added by C<Manifest::Read>,
 #pod see L</"SYNOPSIS">.
 #pod
-#pod Note: Plugins which remove files from distribution (i. e. plugins which do C<FilePruner> role) do
-#pod not affect result of this method.
+#pod Note: The method always returns the same list of files. Plugins which remove files from
+#pod distribution (i. e. plugins which do C<Dist::Zilla::Role::FilePruner> role) do not affect result of
+#pod the method.
 #pod
 #pod =cut
 
@@ -171,8 +165,8 @@ sub find_files {
 
 #pod =attr _files
 #pod
-#pod Array of files (object of C<Dist::Zilla::File::OnDisk> class) listed in the manifest and marked for
-#pod inclusion to the distribution.
+#pod Array of files (object which do C<Dist::Zilla::Role::File> role) listed in the manifest I<and>
+#pod marked for inclusion to the distribution.
 #pod
 #pod C<ArrayRef>, read-only, lazy, initialized with builder.
 #pod
@@ -201,11 +195,11 @@ sub _build_files {
     };
     foreach my $item ( $self->_parse_lines() ) {
         -e $item->{ filename } or $error->( $item, 'does not exist' ) and next;
-        if ( $item->{ marker } eq '/' ) {
+        if ( $item->{ mark } eq '/' ) {
             -d _ or $error->( $item, 'is not a directory' ) and next;
         } else {
             -f _ or $error->( $item, 'is not a plain file' ) and next;
-            if ( $item->{ marker } ne '-' ) {
+            if ( $item->{ mark } ne '-' ) {
                 my $file = Dist::Zilla::File::OnDisk->new( { name => $item->{ filename } } );
                 push( @$files, $file );
             };
@@ -268,10 +262,10 @@ sub _build_lines {
 #pod =for :list
 #pod = filename
 #pod Parsed filename (single-quoted filenames are unquoted, escape sequences are evaluated, if any).
-#pod = marker
-#pod Marker.
+#pod = mark
+#pod Mark.
 #pod = comment
-#pod File comment, leading and trailed whitespaces are stripped.
+#pod File comment, leading and trailing whitespaces are stripped.
 #pod = line
 #pod Number of manifest line the file listed in.
 #pod
@@ -280,7 +274,7 @@ sub _build_lines {
 my %RE = (
     filename => qr{ ' (*PRUNE) (?: [^'\\] ++ | \\ ['\\] ?+ ) ++ ' | \S ++ }x,
         # ^ TODO: Use Regexp::Common for quoted filename?
-    marker   => qr{ [#/+-] }x,
+    mark     => qr{ [#/+-] }x,
     comment  => qr{ . *? }x,
 );
 
@@ -303,7 +297,7 @@ sub _parse_lines {
             (*PRUNE)                        # requires perl v5.10
             (?:
                 \s ++
-                ( $RE{ marker } )
+                ( $RE{ mark } )
                 (*PRUNE)
                 (?:
                     \s ++
@@ -313,7 +307,7 @@ sub _parse_lines {
             \s *
             \z
         }x and do {
-            my ( $filename, $marker, $comment ) = ( $1, $2, $3 );
+            my ( $filename, $mark, $comment ) = ( $1, $2, $3 );
             if ( $filename =~ s{ \A ' ( . * ) ' \z }{ $1 }ex ) {
                 $filename =~ s{  \\ ( ['\\] ) }{ $1 }gex;
             };
@@ -329,7 +323,7 @@ sub _parse_lines {
             };
             my $file = {
                 filename => $filename,
-                marker   => $marker // '+',     # requires perl v5.10
+                mark     => $mark  // '+',     # requires perl v5.10
                 comment  => $comment,
                 line     => $n,
             };
@@ -358,13 +352,37 @@ __PACKAGE__->meta->make_immutable;
 
 # --------------------------------------------------------------------------------------------------
 
+#pod =pod
+#pod
+#pod =encoding UTF-8
+#pod
+#pod =head1 WHAT?
+#pod
+#pod C<Dist-Zilla-Plugin-Manifest-Read> (or C<Manifest::Read> for brevity) is a C<Dist::Zilla> plugin. It reads
+#pod I<annotated source> manifest, checks existence of all listed files and directories, and adds
+#pod selected files to the distribution. C<Manifest::Read> also does C<FileFinder> role, providing the
+#pod list of added files for other plugins.
+#pod
+#pod =cut
+
+
 #pod =head1 SEE ALSO
 #pod
 #pod =for :list
 #pod = L<Dist::Zilla>
 #pod = L<Dist::Zilla::Role::FileGatherer>
 #pod = L<Dist::Zilla::Role::ErrorLogger>
-#pod = L<Dist::Zilla::Plugin::GatherFromManifest>
+#pod
+#pod =head1 COPYRIGHT AND LICENSE
+#pod
+#pod Copyright (C) 2015 Van de Bugger
+#pod
+#pod License GPLv3+: The GNU General Public License version 3 or later
+#pod <http://www.gnu.org/licenses/gpl-3.0.txt>.
+#pod
+#pod This is free software: you are free to change and redistribute it. There is
+#pod NO WARRANTY, to the extent permitted by law.
+#pod
 #pod
 #pod =cut
 
@@ -378,16 +396,23 @@ __END__
 
 =head1 NAME
 
-Dist::Zilla::Plugin::Manifest::Read - Read extended MANIFEST file
+Dist::Zilla::Plugin::Manifest::Read - Read annotated source manifest
 
 =head1 VERSION
 
-Version v0.3.2, released on 2015-09-25 21:26 UTC.
+Version v0.3.3, released on 2015-10-03 11:56 UTC.
+
+=head1 WHAT?
+
+C<Dist-Zilla-Plugin-Manifest-Read> (or C<Manifest::Read> for brevity) is a C<Dist::Zilla> plugin. It reads
+I<annotated source> manifest, checks existence of all listed files and directories, and adds
+selected files to the distribution. C<Manifest::Read> also does C<FileFinder> role, providing the
+list of added files for other plugins.
 
 This is C<Dist::Zilla::Plugin::Manifest::Read> module documentation. Read this if you are going to hack or
-extend C<Dist-Zilla-Plugin-Manifest-Read>, or use it programmatically.
+extend C<Manifest::Read>, or use it programmatically.
 
-If you want to have annotated manifest in your source, read the L<user manual|Dist::Zilla::Plugin::Manifest::Read::Manual>.
+If you want to have annotated source manifest, read the L<user manual|Dist::Zilla::Plugin::Manifest::Read::Manual>.
 General topics like getting source, building, installing, bug reporting and some others are covered
 in the F<README>.
 
@@ -399,7 +424,7 @@ In your plugin:
     # (files not included into distrubution are not iterated):
     my $files = $self->zilla->plugin_named( 'Manifest::Read' )->find_files();
     for my $file ( @$files ) {
-        …
+        ...
     };
 
 =head1 DESCRIPTION
@@ -427,8 +452,8 @@ C<Object>, read-only.
 
 =head2 _files
 
-Array of files (object of C<Dist::Zilla::File::OnDisk> class) listed in the manifest and marked for
-inclusion to the distribution.
+Array of files (object which do C<Dist::Zilla::Role::File> role) listed in the manifest I<and>
+marked for inclusion to the distribution.
 
 C<ArrayRef>, read-only, lazy, initialized with builder.
 
@@ -443,20 +468,20 @@ C<ArrayRef[Str]>, read-only, lazy, initialized with builder.
 =head2 gather_files
 
 This method fulfills L<Dist::Zilla::Role::FileGatherer> role requirement. It adds files listed in
-manifest to distribution. Files marked to exclude from distribution and directories are not added,
-though.
+manifest to distribution (and to C<_files>). Files marked to exclude from distribution and
+directories are not added.
 
 =head2 find_files
 
-This method fulfills L<Dist::Zilla::Role::FileFinder> role requirement. It returns C<ArrayRef> of
-files (objects of C<Dist::Zilla::File::OnDisk> class), listed in manifest and marked for inclusion
-to the distribution.
+This method fulfills L<Dist::Zilla::Role::FileFinder> role requirement. It simply returns a copy of
+C<_files> attribute.
 
 This method can be called by other plugins to iterate through files added by C<Manifest::Read>,
 see L</"SYNOPSIS">.
 
-Note: Plugins which remove files from distribution (i. e. plugins which do C<FilePruner> role) do
-not affect result of this method.
+Note: The method always returns the same list of files. Plugins which remove files from
+distribution (i. e. plugins which do C<Dist::Zilla::Role::FilePruner> role) do not affect result of
+the method.
 
 =head2 _parse_lines
 
@@ -474,13 +499,13 @@ The method returns list of hashrefs, a hash per file. Each hash has following ke
 
 Parsed filename (single-quoted filenames are unquoted, escape sequences are evaluated, if any).
 
-=item marker
+=item mark
 
-Marker.
+Mark.
 
 =item comment
 
-File comment, leading and trailed whitespaces are stripped.
+File comment, leading and trailing whitespaces are stripped.
 
 =item line
 
@@ -498,8 +523,6 @@ Number of manifest line the file listed in.
 
 =item L<Dist::Zilla::Role::ErrorLogger>
 
-=item L<Dist::Zilla::Plugin::GatherFromManifest>
-
 =back
 
 =head1 AUTHOR
@@ -508,19 +531,12 @@ Van de Bugger <van.de.bugger@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright © 2015 Van de Bugger
+Copyright (C) 2015 Van de Bugger
 
-This file is part of perl-Dist-Zilla-Plugin-Manifest-Read.
+License GPLv3+: The GNU General Public License version 3 or later
+<http://www.gnu.org/licenses/gpl-3.0.txt>.
 
-perl-Dist-Zilla-Plugin-Manifest-Read is free software: you can redistribute it and/or modify it
-under the terms of the GNU General Public License as published by the Free Software Foundation,
-either version 3 of the License, or (at your option) any later version.
-
-perl-Dist-Zilla-Plugin-Manifest-Read is distributed in the hope that it will be useful, but
-WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
-PARTICULAR PURPOSE. See the GNU General Public License for more details.
-
-You should have received a copy of the GNU General Public License along with
-perl-Dist-Zilla-Plugin-Manifest-Read. If not, see <http://www.gnu.org/licenses/>.
+This is free software: you are free to change and redistribute it. There is
+NO WARRANTY, to the extent permitted by law.
 
 =cut
